from . import base

class DataFormat(base.TypedDataPipelineObject): pass


class CSV(DataFormat): pass


class Custom(DataFormat): pass


class DynamoDBDataFormat(DataFormat): pass


class DynamoDBExportDataFormat(DataFormat): pass


class RegEx(DataFormat): pass


class TSV(DataFormat): pass
